# logtator

features:
 * makes logging just work
 * bind parameters to loggers

roadmap:
 - [ ] properly configure ruffus/mypy
 - [ ] fix errors from ruffus/mypy
 - [ ] add tests
 - [ ] verify DD works
 - [ ] verify sentry works
 - [ ] add option to set log levels for specific loggers
 - [ ] make bind thread safe
 - [ ] add colors
 - [ ] pretty print exceptions in human readable format
 - [ ] add loguru support
